
Pyfolio-Tekton
==============

Pyfolio-Tekton is a Python library for performance and risk analysis of financial portfolios, which is a fork of Pyfolio maintained by Tekton Ventures. It works well with the Zipline open source backtesting library.

At the core of Pyfolio-Tekton is a so-called tear sheet that consists of various individual plots that provide a comprehensive performance overview of a portfolio.

This package is designed to fix the error in pydatetime.

To install Pyfolio-Tekton, you can use pip eg. pip install pyfolio-tekton
